@@ -1,6 +1,6 @@
 import pytest
 from sympy import Matrix
-from enp.linear_algebra import *
+from enp.linalg import *
 
 
 def test_transpose2d():
