@@ -1,5 +1,5 @@
 import numpy as np
-from enp.linear_algebra_additional import *
+from enp.linalg import *
 
 
 def test_number_of_free_variables_in_ax_zero():
